Attribute VB_Name = "M6502"
'+========================================+'
'| M6502/65C02/65SC02/2A03 emulator.      |'
'| By Don Jarrett, 2003                   |'
'|                                        |'
'|Big thanks goes out to Kevin Horton     |'
'|who stayed up long nights helping me    |'
'|out!!!!!!! Thanks Kev!                  |'
'| Also thanks to Akilla & doppel!        |'
'|                                        |'
'+========================================+'
Option Explicit

Public Const S_FLAG As Byte = &H80, V_FLAG As Byte = &H40, R_FLAG As Byte = &H20, B_FLAG As Byte = &H10, D_FLAG As Byte = &H8, I_FLAG As Byte = &H4, Z_FLAG As Byte = &H2, C_FLAG As Byte = &H1
Public Const S_OFF As Byte = &H7F, V_OFF As Byte = &HBF, B_OFF As Byte = &HEF, D_OFF As Byte = &HF7, I_OFF  As Byte = &HFB, Z_OFF As Byte = &HFD, C_OFF As Byte = &HFE
Public Sub M6502_Reset() 'reset the cpu.
    
    A = 0
    X = 0
    Y = 0
    S = &HFF
    P = (R_FLAG Or D_FLAG) 'Set Reserved flag and Decimal mode.
    PC = (Read6502(M6502RESET + 1) * &H100&) + Read6502(M6502RESET)
    Debug.Print "CPU Reset to $" & Hex$(PC) & " [ " & PC & " ];"

End Sub
Public Sub M6502_IRQ() 'Interrupt ReQuest
    If (P And I_FLAG) = 0 Then
        Write6502 (S + &H100&), (PC \ &H100&)
        S = (S - 1) And &HFF
        Write6502 (S + &H100&), (PC And &HFF)
        S = (S - 1) And &HFF
        Write6502 (S + &H100&), (P And B_OFF)
        S = (S - 1) And &HFF
        P = (P Or I_FLAG)
        PC = (Read6502(M6502IRQ + 1) * &H100&) + Read6502(M6502IRQ)
        Ticks = Ticks + 7
    End If
End Sub
Public Sub M6502_NMI() 'Non-Maskable Interrupt
    Write6502 (S + &H100&), (PC \ &H100&)
    S = (S - 1) And &HFF
    Write6502 (S + &H100&), (PC And &HFF)
    S = (S - 1) And &HFF
    Write6502 (S + &H100&), P
    S = (S - 1) And &HFF
    PC = (Read6502(M6502NMI + 1) * &H100&) + Read6502(M6502NMI)
    Ticks = Ticks - 7
End Sub
Public Sub M6502_Init(ByVal cpuTicks As Long, Optional ByVal CPUTYPE As Byte = CPU_M6502)
    'initialize our instructions and addressing modes, and clock ticks.
    'clear arrays.
    Erase AddressingModes, Instructions, ClockTicks
    CPU_TYPE = CPUTYPE 'Set CPU_TYPE
    CPU_Ticks = cpuTicks
    M6502_resetTicks
    Dim i As Long
    For i = 0 To 15
        pow2(i) = 2 ^ i
    Next i
    Dim loopI As Long
    For loopI = 0 To 255 'fill with errors.
        AddressingModes(loopI) = ADR_ERA: Instructions(loopI) = INS_ERA: ClockTicks(loopI) = 0
    Next loopI
    Select Case CPU_TYPE 'here we figure which 6502 we are using, then set up the addressing/instructions for it.
        Case CPU_M6502, CPU_M6510, CPU_M2A03 'NES, Atari, etc. These 3 CPUs all use the same sets
            'ADC
            AddressingModes(&H61) = ADR_PIX: Instructions(&H61) = INS_ADC: ClockTicks(&H61) = 6
            AddressingModes(&H65) = ADR_ZP: Instructions(&H65) = INS_ADC: ClockTicks(&H65) = 3
            AddressingModes(&H69) = ADR_IMM: Instructions(&H69) = INS_ADC: ClockTicks(&H69) = 3
            AddressingModes(&H6D) = ADR_ABS: Instructions(&H6D) = INS_ADC: ClockTicks(&H6D) = 4
            AddressingModes(&H71) = ADR_PII: Instructions(&H71) = INS_ADC: ClockTicks(&H71) = 5
            AddressingModes(&H75) = ADR_ZPX: Instructions(&H75) = INS_ADC: ClockTicks(&H75) = 4
            AddressingModes(&H79) = ADR_INY: Instructions(&H79) = INS_ADC: ClockTicks(&H79) = 4
            AddressingModes(&H7D) = ADR_INX: Instructions(&H7D) = INS_ADC: ClockTicks(&H7D) = 4
            'AND
            AddressingModes(&H21) = ADR_PIX: Instructions(&H21) = INS_AND: ClockTicks(&H21) = 6
            AddressingModes(&H25) = ADR_ZP: Instructions(&H25) = INS_AND: ClockTicks(&H25) = 3
            AddressingModes(&H29) = ADR_IMM: Instructions(&H29) = INS_AND: ClockTicks(&H29) = 3
            AddressingModes(&H2D) = ADR_ABS: Instructions(&H2D) = INS_AND: ClockTicks(&H2D) = 4
            AddressingModes(&H31) = ADR_PII: Instructions(&H31) = INS_AND: ClockTicks(&H31) = 5
            AddressingModes(&H35) = ADR_ZPX: Instructions(&H35) = INS_AND: ClockTicks(&H35) = 4
            AddressingModes(&H39) = ADR_INY: Instructions(&H39) = INS_AND: ClockTicks(&H39) = 4
            AddressingModes(&H3D) = ADR_INX: Instructions(&H3D) = INS_AND: ClockTicks(&H3D) = 4
            'ASL
            AddressingModes(&H6) = ADR_ZP: Instructions(&H6) = INS_ASL: ClockTicks(&H6) = 5
            AddressingModes(&HA) = ADR_ACC: Instructions(&HA) = INS_ASL: ClockTicks(&HA) = 2
            AddressingModes(&HE) = ADR_ABS: Instructions(&HE) = INS_ASL: ClockTicks(&HE) = 6
            AddressingModes(&H16) = ADR_ZPX: Instructions(&H16) = INS_ASL: ClockTicks(&H16) = 6
            AddressingModes(&H1E) = ADR_INX: Instructions(&H1E) = INS_ASL: ClockTicks(&H1E) = 7
            'BCC
            AddressingModes(&H90) = ADR_IMP: Instructions(&H90) = INS_BCC: ClockTicks(&H90) = 2
            'BCS
            AddressingModes(&HB0) = ADR_IMP: Instructions(&HB0) = INS_BCS: ClockTicks(&HB0) = 2
            'BEQ
            AddressingModes(&HF0) = ADR_IMP: Instructions(&HF0) = INS_BEQ: ClockTicks(&HF0) = 2
            'BIT
            AddressingModes(&H24) = ADR_ZP: Instructions(&H24) = INS_BIT: ClockTicks(&H24) = 3
            AddressingModes(&H2C) = ADR_ABS: Instructions(&H2C) = INS_BIT: ClockTicks(&H2C) = 4
            AddressingModes(&H34) = ADR_ZPX: Instructions(&H34) = INS_BIT: ClockTicks(&H34) = 4
            AddressingModes(&H3C) = ADR_INX: Instructions(&H3C) = INS_BIT: ClockTicks(&H3C) = 4
            AddressingModes(&H89) = ADR_IMM: Instructions(&H89) = INS_BIT: ClockTicks(&H89) = 2
            'BMI
            AddressingModes(&H30) = ADR_IMP: Instructions(&H30) = INS_BMI: ClockTicks(&H30) = 2
            'BNE
            AddressingModes(&HD0) = ADR_IMP: Instructions(&HD0) = INS_BNE: ClockTicks(&HD0) = 2
            'BPL
            AddressingModes(&H10) = ADR_IMP: Instructions(&H10) = INS_BPL: ClockTicks(&H10) = 2
            'BRK
            AddressingModes(&H0) = ADR_IMP: Instructions(&H0) = INS_BRK: ClockTicks(&H0) = 7
            'BVC
            AddressingModes(&H50) = ADR_IMP: Instructions(&H50) = INS_BVC: ClockTicks(&H50) = 2
            'BVS
            AddressingModes(&H70) = ADR_IMP: Instructions(&H70) = INS_BVS: ClockTicks(&H70) = 2
            'CLC
            AddressingModes(&H18) = ADR_IMP: Instructions(&H18) = INS_CLC: ClockTicks(&H18) = 2
            'CLD
            AddressingModes(&HD8) = ADR_IMP: Instructions(&HD8) = INS_CLD: ClockTicks(&HD8) = 2
            'CLI
            AddressingModes(&H58) = ADR_IMP: Instructions(&H58) = INS_CLI: ClockTicks(&H58) = 2
            'CLV
            AddressingModes(&HB8) = ADR_IMP: Instructions(&HB8) = INS_CLV: ClockTicks(&HB8) = 2
            'CMP
            AddressingModes(&HC1) = ADR_PIX: Instructions(&HC1) = INS_CMP: ClockTicks(&HC1) = 6
            AddressingModes(&HC5) = ADR_ZP: Instructions(&HC5) = INS_CMP: ClockTicks(&HC5) = 3
            AddressingModes(&HC9) = ADR_IMM: Instructions(&HC9) = INS_CMP: ClockTicks(&HC9) = 3
            AddressingModes(&HCD) = ADR_ABS: Instructions(&HCD) = INS_CMP: ClockTicks(&HCD) = 4
            AddressingModes(&HD1) = ADR_PII: Instructions(&HD1) = INS_CMP: ClockTicks(&HD1) = 5
            AddressingModes(&HD5) = ADR_ZPX: Instructions(&HD5) = INS_CMP: ClockTicks(&HD5) = 4
            AddressingModes(&HD9) = ADR_INY: Instructions(&HD9) = INS_CMP: ClockTicks(&HD9) = 5
            AddressingModes(&HDD) = ADR_INX: Instructions(&HDD) = INS_CMP: ClockTicks(&HDD) = 5
            'CPX
            AddressingModes(&HE0) = ADR_IMM: Instructions(&HE0) = INS_CPX: ClockTicks(&HE0) = 3
            AddressingModes(&HE4) = ADR_ZP: Instructions(&HE4) = INS_CPX: ClockTicks(&HE4) = 3
            AddressingModes(&HEC) = ADR_ABS: Instructions(&HEC) = INS_CPX: ClockTicks(&HEC) = 4
            'CPY
            AddressingModes(&HC0) = ADR_IMM: Instructions(&HC0) = INS_CPY: ClockTicks(&HC0) = 3
            AddressingModes(&HC4) = ADR_ZP: Instructions(&HC4) = INS_CPY: ClockTicks(&HC4) = 3
            AddressingModes(&HCC) = ADR_ABS: Instructions(&HCC) = INS_CPY: ClockTicks(&HCC) = 4
            'DEC
            AddressingModes(&HC6) = ADR_ZP: Instructions(&HC6) = INS_DEC: ClockTicks(&HC6) = 5
            AddressingModes(&HCE) = ADR_ABS: Instructions(&HCE) = INS_DEC: ClockTicks(&HCE) = 6
            AddressingModes(&HD6) = ADR_ZPX: Instructions(&HD6) = INS_DEC: ClockTicks(&HD6) = 6
            AddressingModes(&HDE) = ADR_INX: Instructions(&HDE) = INS_DEC: ClockTicks(&HDE) = 7
            'DEX
            AddressingModes(&HCA) = ADR_IMP: Instructions(&HCA) = INS_DEX: ClockTicks(&HCA) = 2
            'DEY
            AddressingModes(&H88) = ADR_IMP: Instructions(&H88) = INS_DEY: ClockTicks(&H88) = 2
            'EOR
            AddressingModes(&H41) = ADR_PIX: Instructions(&H41) = INS_EOR: ClockTicks(&H41) = 6
            AddressingModes(&H45) = ADR_ZP: Instructions(&H45) = INS_EOR: ClockTicks(&H45) = 3
            AddressingModes(&H49) = ADR_IMM: Instructions(&H49) = INS_EOR: ClockTicks(&H49) = 3
            AddressingModes(&H4D) = ADR_ABS: Instructions(&H4D) = INS_EOR: ClockTicks(&H4D) = 4
            AddressingModes(&H51) = ADR_PII: Instructions(&H51) = INS_EOR: ClockTicks(&H51) = 5
            AddressingModes(&H55) = ADR_ZPX: Instructions(&H55) = INS_EOR: ClockTicks(&H55) = 4
            AddressingModes(&H59) = ADR_INY: Instructions(&H59) = INS_EOR: ClockTicks(&H59) = 4
            AddressingModes(&H5D) = ADR_INX: Instructions(&H5D) = INS_EOR: ClockTicks(&H5D) = 4
            'INC
            AddressingModes(&HE6) = ADR_ZP: Instructions(&HE6) = INS_INC: ClockTicks(&HE6) = 5
            AddressingModes(&HEE) = ADR_ABS: Instructions(&HEE) = INS_INC: ClockTicks(&HEE) = 6
            AddressingModes(&HF6) = ADR_ZPX: Instructions(&HF6) = INS_INC: ClockTicks(&HF6) = 6
            AddressingModes(&HFE) = ADR_INX: Instructions(&HFE) = INS_INC: ClockTicks(&HFE) = 7
            'INX
            AddressingModes(&HE8) = ADR_IMP: Instructions(&HE8) = INS_INX: ClockTicks(&HE8) = 2
            'INY
            AddressingModes(&HC8) = ADR_IMP: Instructions(&HC8) = INS_INY: ClockTicks(&HC8) = 2
            'JMP
            AddressingModes(&H4C) = ADR_ABS: Instructions(&H4C) = INS_JMP: ClockTicks(&H4C) = 3
            AddressingModes(&H6C) = ADR_IND: Instructions(&H6C) = INS_JMP: ClockTicks(&H6C) = 5
            'JSR
            AddressingModes(&H20) = ADR_IMP: Instructions(&H20) = INS_JSR: ClockTicks(&H20) = 6
            'LDA
            AddressingModes(&HA1) = ADR_PIX: Instructions(&HA1) = INS_LDA: ClockTicks(&HA1) = 6
            AddressingModes(&HA5) = ADR_ZP: Instructions(&HA5) = INS_LDA: ClockTicks(&HA5) = 3
            AddressingModes(&HA9) = ADR_IMM: Instructions(&HA9) = INS_LDA: ClockTicks(&HA9) = 3
            AddressingModes(&HAD) = ADR_ABS: Instructions(&HAD) = INS_LDA: ClockTicks(&HAD) = 6
            AddressingModes(&HB1) = ADR_PII: Instructions(&HB1) = INS_LDA: ClockTicks(&HB1) = 5
            AddressingModes(&HB5) = ADR_ZPX: Instructions(&HB5) = INS_LDA: ClockTicks(&HB5) = 4
            AddressingModes(&HB9) = ADR_INY: Instructions(&HB9) = INS_LDA: ClockTicks(&HB9) = 4
            AddressingModes(&HBD) = ADR_INX: Instructions(&HBD) = INS_LDA: ClockTicks(&HBD) = 4
            'LDX
            AddressingModes(&HA2) = ADR_IMM: Instructions(&HA2) = INS_LDX: ClockTicks(&HA2) = 3
            AddressingModes(&HA6) = ADR_ZP: Instructions(&HA6) = INS_LDX: ClockTicks(&HA6) = 3
            AddressingModes(&HAE) = ADR_ABS: Instructions(&HAE) = INS_LDX: ClockTicks(&HAE) = 4
            AddressingModes(&HB6) = ADR_ZPY: Instructions(&HB6) = INS_LDX: ClockTicks(&HB6) = 4
            AddressingModes(&HBE) = ADR_INY: Instructions(&HBE) = INS_LDX: ClockTicks(&HBE) = 4
            'LDY
            AddressingModes(&HA0) = ADR_IMM: Instructions(&HA0) = INS_LDY: ClockTicks(&HA0) = 3
            AddressingModes(&HA4) = ADR_ZP: Instructions(&HA4) = INS_LDY: ClockTicks(&HA4) = 3
            AddressingModes(&HAC) = ADR_ABS: Instructions(&HAC) = INS_LDY: ClockTicks(&HAC) = 4
            AddressingModes(&HB4) = ADR_ZPX: Instructions(&HB4) = INS_LDY: ClockTicks(&HB4) = 4
            AddressingModes(&HBC) = ADR_INX: Instructions(&HBC) = INS_LDY: ClockTicks(&HBC) = 4
            'LSR
            AddressingModes(&H46) = ADR_ZP: Instructions(&H46) = INS_LSR: ClockTicks(&H46) = 5
            AddressingModes(&H4A) = ADR_ACC: Instructions(&H4A) = INS_LSR: ClockTicks(&H4A) = 2
            AddressingModes(&H4E) = ADR_ABS: Instructions(&H4E) = INS_LSR: ClockTicks(&H4E) = 6
            AddressingModes(&H56) = ADR_ZPX: Instructions(&H56) = INS_LSR: ClockTicks(&H56) = 6
            AddressingModes(&H5E) = ADR_INX: Instructions(&H5E) = INS_LSR: ClockTicks(&H5E) = 7
            'NOP
            AddressingModes(&HEA) = ADR_IMP: Instructions(&HEA) = INS_NOP: ClockTicks(&HEA) = 2
            'ORA
            AddressingModes(&H1) = ADR_PIX: Instructions(&H1) = INS_ORA: ClockTicks(&H1) = 6
            AddressingModes(&H5) = ADR_ZP: Instructions(&H5) = INS_ORA: ClockTicks(&H5) = 3
            AddressingModes(&H9) = ADR_IMM: Instructions(&H9) = INS_ORA: ClockTicks(&H9) = 3
            AddressingModes(&HD) = ADR_ABS: Instructions(&HD) = INS_ORA: ClockTicks(&HD) = 4
            AddressingModes(&H11) = ADR_PII: Instructions(&H11) = INS_ORA: ClockTicks(&H11) = 5
            AddressingModes(&H15) = ADR_ZPX: Instructions(&H15) = INS_ORA: ClockTicks(&H15) = 4
            AddressingModes(&H19) = ADR_INY: Instructions(&H19) = INS_ORA: ClockTicks(&H19) = 4
            AddressingModes(&H1D) = ADR_INX: Instructions(&H1D) = INS_ORA: ClockTicks(&H1D) = 4
            'PHA
            AddressingModes(&H48) = ADR_IMP: Instructions(&H48) = INS_PHA: ClockTicks(&H48) = 3
            'PHP
            AddressingModes(&H8) = ADR_IMP: Instructions(&H8) = INS_PHP: ClockTicks(&H8) = 3
            'PLA
            AddressingModes(&H68) = ADR_IMP: Instructions(&H68) = INS_PLA: ClockTicks(&H68) = 4
            'PLP
            AddressingModes(&H28) = ADR_IMP: Instructions(&H28) = INS_PLP: ClockTicks(&H28) = 4
            'ROL
            AddressingModes(&H26) = ADR_ZP: Instructions(&H26) = INS_ROL: ClockTicks(&H26) = 5
            AddressingModes(&H2A) = ADR_ACC: Instructions(&H2A) = INS_ROL: ClockTicks(&H2A) = 2
            AddressingModes(&H2E) = ADR_ABS: Instructions(&H2E) = INS_ROL: ClockTicks(&H2E) = 6
            AddressingModes(&H36) = ADR_ZPX: Instructions(&H36) = INS_ROL: ClockTicks(&H36) = 6
            AddressingModes(&H3E) = ADR_INX: Instructions(&H3E) = INS_ROL: ClockTicks(&H3E) = 7
            'ROR
            AddressingModes(&H66) = ADR_ZP: Instructions(&H66) = INS_ROR: ClockTicks(&H66) = 5
            AddressingModes(&H6A) = ADR_ACC: Instructions(&H6A) = INS_ROR: ClockTicks(&H6A) = 2
            AddressingModes(&H6E) = ADR_ABS: Instructions(&H6E) = INS_ROR: ClockTicks(&H6E) = 6
            AddressingModes(&H76) = ADR_ZPX: Instructions(&H76) = INS_ROR: ClockTicks(&H76) = 6
            AddressingModes(&H7E) = ADR_INX: Instructions(&H7E) = INS_ROR: ClockTicks(&H7E) = 7
            'RTI
            AddressingModes(&H40) = ADR_IMP: Instructions(&H40) = INS_RTI: ClockTicks(&H40) = 6
            'RTS
            AddressingModes(&H60) = ADR_IMP: Instructions(&H60) = INS_RTS: ClockTicks(&H60) = 6
            'SBC
            AddressingModes(&HE1) = ADR_PIX: Instructions(&HE1) = INS_SBC: ClockTicks(&HE1) = 6
            AddressingModes(&HE5) = ADR_ZP: Instructions(&HE5) = INS_SBC: ClockTicks(&HE5) = 3
            AddressingModes(&HE9) = ADR_IMM: Instructions(&HE9) = INS_SBC: ClockTicks(&HE9) = 3
            AddressingModes(&HED) = ADR_ABS: Instructions(&HED) = INS_SBC: ClockTicks(&HED) = 4
            AddressingModes(&HF1) = ADR_PII: Instructions(&HF1) = INS_SBC: ClockTicks(&HF1) = 5
            AddressingModes(&HF5) = ADR_ZPX: Instructions(&HF5) = INS_SBC: ClockTicks(&HF5) = 4
            AddressingModes(&HF9) = ADR_INY: Instructions(&HF9) = INS_SBC: ClockTicks(&HF9) = 4
            AddressingModes(&HFD) = ADR_INX: Instructions(&HFD) = INS_SBC: ClockTicks(&HFD) = 4
            'SEC
            AddressingModes(&H38) = ADR_IMP: Instructions(&H38) = INS_SEC: ClockTicks(&H38) = 2
            'SED
            AddressingModes(&HF8) = ADR_IMP: Instructions(&HF8) = INS_SED: ClockTicks(&HF8) = 2
            'SEI
            AddressingModes(&H78) = ADR_IMP: Instructions(&H78) = INS_SEI: ClockTicks(&H78) = 2
            'STA
            AddressingModes(&H81) = ADR_PIX: Instructions(&H81) = INS_STA: ClockTicks(&H81) = 6
            AddressingModes(&H85) = ADR_ZP: Instructions(&H85) = INS_STA: ClockTicks(&H85) = 2
            AddressingModes(&H8D) = ADR_ABS: Instructions(&H8D) = INS_STA: ClockTicks(&H8D) = 4
            AddressingModes(&H91) = ADR_PII: Instructions(&H91) = INS_STA: ClockTicks(&H91) = 6
            AddressingModes(&H95) = ADR_ZPX: Instructions(&H95) = INS_STA: ClockTicks(&H95) = 4
            AddressingModes(&H99) = ADR_INY: Instructions(&H99) = INS_STA: ClockTicks(&H99) = 5
            AddressingModes(&H9D) = ADR_INX: Instructions(&H9D) = INS_STA: ClockTicks(&H9D) = 5
            'STX
            AddressingModes(&H86) = ADR_ZP: Instructions(&H86) = INS_STX: ClockTicks(&H86) = 2
            AddressingModes(&H8E) = ADR_ABS: Instructions(&H8E) = INS_STX: ClockTicks(&H8E) = 4
            AddressingModes(&H96) = ADR_ZPY: Instructions(&H96) = INS_STX: ClockTicks(&H96) = 4
            'STY
            AddressingModes(&H84) = ADR_ZP: Instructions(&H84) = INS_STY: ClockTicks(&H84) = 2
            AddressingModes(&H8C) = ADR_ABS: Instructions(&H8C) = INS_STY: ClockTicks(&H8C) = 4
            AddressingModes(&H94) = ADR_ZPX: Instructions(&H94) = INS_STY: ClockTicks(&H94) = 4
            'TAX
            AddressingModes(&HAA) = ADR_IMP: Instructions(&HAA) = INS_TAX: ClockTicks(&HAA) = 2
            'TAY
            AddressingModes(&HA8) = ADR_IMP: Instructions(&HA8) = INS_TAY: ClockTicks(&HA8) = 2
            'TSX
            AddressingModes(&HBA) = ADR_IMP: Instructions(&HBA) = INS_TSX: ClockTicks(&HBA) = 2
            'TXA
            AddressingModes(&H8A) = ADR_IMP: Instructions(&H8A) = INS_TXA: ClockTicks(&H8A) = 2
            'TXS
            AddressingModes(&H9A) = ADR_IMP: Instructions(&H9A) = INS_TXS: ClockTicks(&H9A) = 2
            'TYA
            AddressingModes(&H98) = ADR_IMP: Instructions(&H98) = INS_TYA: ClockTicks(&H98) = 2
        Case CPU_M65C02 'Lynx, etc.
            'ADC
            AddressingModes(&H61) = ADR_PIX: Instructions(&H61) = INS_ADC: ClockTicks(&H61) = 6
            AddressingModes(&H65) = ADR_ZP: Instructions(&H65) = INS_ADC: ClockTicks(&H65) = 3
            AddressingModes(&H69) = ADR_IMM: Instructions(&H69) = INS_ADC: ClockTicks(&H69) = 3
            AddressingModes(&H6D) = ADR_ABS: Instructions(&H6D) = INS_ADC: ClockTicks(&H6D) = 4
            AddressingModes(&H71) = ADR_PII: Instructions(&H71) = INS_ADC: ClockTicks(&H71) = 5
            AddressingModes(&H72) = ADR_IZP: Instructions(&H72) = INS_ADC: ClockTicks(&H72) = 3
            AddressingModes(&H75) = ADR_ZPX: Instructions(&H75) = INS_ADC: ClockTicks(&H75) = 4
            AddressingModes(&H79) = ADR_INY: Instructions(&H79) = INS_ADC: ClockTicks(&H79) = 4
            AddressingModes(&H7D) = ADR_INX: Instructions(&H7D) = INS_ADC: ClockTicks(&H7D) = 4
            'AND
            AddressingModes(&H21) = ADR_PIX: Instructions(&H21) = INS_AND: ClockTicks(&H21) = 6
            AddressingModes(&H25) = ADR_ZP: Instructions(&H25) = INS_AND: ClockTicks(&H25) = 3
            AddressingModes(&H29) = ADR_IMM: Instructions(&H29) = INS_AND: ClockTicks(&H29) = 3
            AddressingModes(&H2D) = ADR_ABS: Instructions(&H2D) = INS_AND: ClockTicks(&H2D) = 4
            AddressingModes(&H31) = ADR_PII: Instructions(&H31) = INS_AND: ClockTicks(&H31) = 5
            AddressingModes(&H32) = ADR_IZP: Instructions(&H32) = INS_AND: ClockTicks(&H32) = 3
            AddressingModes(&H35) = ADR_ZPX: Instructions(&H35) = INS_AND: ClockTicks(&H35) = 4
            AddressingModes(&H39) = ADR_INY: Instructions(&H39) = INS_AND: ClockTicks(&H39) = 4
            AddressingModes(&H3D) = ADR_INX: Instructions(&H3D) = INS_AND: ClockTicks(&H3D) = 4
            'ASL
            AddressingModes(&H6) = ADR_ZP: Instructions(&H6) = INS_ASL: ClockTicks(&H6) = 5
            AddressingModes(&HA) = ADR_ACC: Instructions(&HA) = INS_ASL: ClockTicks(&HA) = 2
            AddressingModes(&HE) = ADR_ABS: Instructions(&HE) = INS_ASL: ClockTicks(&HE) = 6
            AddressingModes(&H16) = ADR_ZPX: Instructions(&H16) = INS_ASL: ClockTicks(&H16) = 6
            AddressingModes(&H1E) = ADR_INX: Instructions(&H1E) = INS_ASL: ClockTicks(&H1E) = 7
            'BBR
            AddressingModes(&HF) = ADR_ZP: Instructions(&HF) = INS_BBR: ClockTicks(&HF) = 2
            AddressingModes(&H1F) = ADR_ZP: Instructions(&H1F) = INS_BBR: ClockTicks(&H1F) = 2
            AddressingModes(&H2F) = ADR_ZP: Instructions(&H2F) = INS_BBR: ClockTicks(&H2F) = 2
            AddressingModes(&H3F) = ADR_ZP: Instructions(&H3F) = INS_BBR: ClockTicks(&H3F) = 2
            AddressingModes(&H4F) = ADR_ZP: Instructions(&H4F) = INS_BBR: ClockTicks(&H4F) = 2
            AddressingModes(&H5F) = ADR_ZP: Instructions(&H5F) = INS_BBR: ClockTicks(&H5F) = 2
            AddressingModes(&H6F) = ADR_ZP: Instructions(&H6F) = INS_BBR: ClockTicks(&H6F) = 2
            AddressingModes(&H7F) = ADR_ZP: Instructions(&H7F) = INS_BBR: ClockTicks(&H7F) = 2
            'BBS
            AddressingModes(&H8F) = ADR_ZP: Instructions(&H8F) = INS_BBS: ClockTicks(&H8F) = 2
            AddressingModes(&H9F) = ADR_ZP: Instructions(&H9F) = INS_BBS: ClockTicks(&H9F) = 2
            AddressingModes(&HAF) = ADR_ZP: Instructions(&HAF) = INS_BBS: ClockTicks(&HAF) = 2
            AddressingModes(&HBF) = ADR_ZP: Instructions(&HBF) = INS_BBS: ClockTicks(&HBF) = 2
            AddressingModes(&HCF) = ADR_ZP: Instructions(&HCF) = INS_BBS: ClockTicks(&HCF) = 2
            AddressingModes(&HDF) = ADR_ZP: Instructions(&HDF) = INS_BBS: ClockTicks(&HDF) = 2
            AddressingModes(&HEF) = ADR_ZP: Instructions(&HEF) = INS_BBS: ClockTicks(&HEF) = 2
            AddressingModes(&HFF) = ADR_ZP: Instructions(&HFF) = INS_BBS: ClockTicks(&HFF) = 2
            'BCC
            AddressingModes(&H90) = ADR_IMP: Instructions(&H90) = INS_BCC: ClockTicks(&H90) = 2
            'BCS
            AddressingModes(&HB0) = ADR_IMP: Instructions(&HB0) = INS_BCS: ClockTicks(&HB0) = 2
            'BEQ
            AddressingModes(&HF0) = ADR_IMP: Instructions(&HF0) = INS_BEQ: ClockTicks(&HF0) = 2
            'BIT
            AddressingModes(&H24) = ADR_ZP: Instructions(&H24) = INS_BIT: ClockTicks(&H24) = 3
            AddressingModes(&H2C) = ADR_ABS: Instructions(&H2C) = INS_BIT: ClockTicks(&H2C) = 4
            AddressingModes(&H34) = ADR_ZPX: Instructions(&H34) = INS_BIT: ClockTicks(&H34) = 4
            AddressingModes(&H3C) = ADR_INX: Instructions(&H3C) = INS_BIT: ClockTicks(&H3C) = 4
            AddressingModes(&H89) = ADR_IMM: Instructions(&H89) = INS_BIT: ClockTicks(&H89) = 2
            'BMI
            AddressingModes(&H30) = ADR_IMP: Instructions(&H30) = INS_BMI: ClockTicks(&H30) = 2
            'BNE
            AddressingModes(&HD0) = ADR_IMP: Instructions(&HD0) = INS_BNE: ClockTicks(&HD0) = 2
            'BPL
            AddressingModes(&H10) = ADR_IMP: Instructions(&H10) = INS_BPL: ClockTicks(&H10) = 2
            'BRA
            AddressingModes(&H80) = ADR_IMP: Instructions(&H80) = INS_BRA: ClockTicks(&H80) = 2
            'BRK
            AddressingModes(&H0) = ADR_IMP: Instructions(&H0) = INS_BRK: ClockTicks(&H0) = 7
            'BVC
            AddressingModes(&H50) = ADR_IMP: Instructions(&H50) = INS_BVC: ClockTicks(&H50) = 2
            'BVS
            AddressingModes(&H70) = ADR_IMP: Instructions(&H70) = INS_BVS: ClockTicks(&H70) = 2
            'CLC
            AddressingModes(&H18) = ADR_IMP: Instructions(&H18) = INS_CLC: ClockTicks(&H18) = 2
            'CLD
            AddressingModes(&HD8) = ADR_IMP: Instructions(&HD8) = INS_CLD: ClockTicks(&HD8) = 2
            'CLI
            AddressingModes(&H58) = ADR_IMP: Instructions(&H58) = INS_CLI: ClockTicks(&H58) = 2
            'CLV
            AddressingModes(&HB8) = ADR_IMP: Instructions(&HB8) = INS_CLV: ClockTicks(&HB8) = 2
            'CMP
            AddressingModes(&HC1) = ADR_PIX: Instructions(&HC1) = INS_CMP: ClockTicks(&HC1) = 6
            AddressingModes(&HC5) = ADR_ZP: Instructions(&HC5) = INS_CMP: ClockTicks(&HC5) = 3
            AddressingModes(&HC9) = ADR_IMM: Instructions(&HC9) = INS_CMP: ClockTicks(&HC9) = 3
            AddressingModes(&HCD) = ADR_ABS: Instructions(&HCD) = INS_CMP: ClockTicks(&HCD) = 4
            AddressingModes(&HD1) = ADR_PII: Instructions(&HD1) = INS_CMP: ClockTicks(&HD1) = 5
            AddressingModes(&HD2) = ADR_IZP: Instructions(&HD2) = INS_CMP: ClockTicks(&HD2) = 3
            AddressingModes(&HD5) = ADR_ZPX: Instructions(&HD5) = INS_CMP: ClockTicks(&HD5) = 4
            AddressingModes(&HD9) = ADR_INY: Instructions(&HD9) = INS_CMP: ClockTicks(&HD9) = 4
            'CPX
            AddressingModes(&HE0) = ADR_IMM: Instructions(&HE0) = INS_CPX: ClockTicks(&HE0) = 3
            AddressingModes(&HE4) = ADR_ZP: Instructions(&HE4) = INS_CPX: ClockTicks(&HE4) = 3
            AddressingModes(&HEC) = ADR_ABS: Instructions(&HEC) = INS_CPX: ClockTicks(&HEC) = 4
            'CPY
            AddressingModes(&HC0) = ADR_IMM: Instructions(&HC0) = INS_CPY: ClockTicks(&HC0) = 3
            AddressingModes(&HC4) = ADR_ZP: Instructions(&HC4) = INS_CPY: ClockTicks(&HC4) = 3
            AddressingModes(&HCC) = ADR_ABS: Instructions(&HCC) = INS_CPY: ClockTicks(&HCC) = 4
            'DEA
            AddressingModes(&H3A) = ADR_IMP: Instructions(&H3A) = INS_DEA: ClockTicks(&H3A) = 2
            'DEC
            AddressingModes(&HC6) = ADR_ZP: Instructions(&HC6) = INS_DEC: ClockTicks(&HC6) = 5
            AddressingModes(&HCE) = ADR_ABS: Instructions(&HCE) = INS_DEC: ClockTicks(&HCE) = 6
            AddressingModes(&HD6) = ADR_ZPX: Instructions(&HD6) = INS_DEC: ClockTicks(&HD6) = 6
            AddressingModes(&HDE) = ADR_INX: Instructions(&HDE) = INS_DEC: ClockTicks(&HDE) = 7
            'DEX
            AddressingModes(&HCA) = ADR_IMP: Instructions(&HCA) = INS_DEX: ClockTicks(&HCA) = 2
            'DEY
            AddressingModes(&H88) = ADR_IMP: Instructions(&H88) = INS_DEY: ClockTicks(&H88) = 2
            'EOR
            AddressingModes(&H41) = ADR_PIX: Instructions(&H41) = INS_EOR: ClockTicks(&H41) = 6
            AddressingModes(&H45) = ADR_ZP: Instructions(&H45) = INS_EOR: ClockTicks(&H45) = 3
            AddressingModes(&H49) = ADR_IMM: Instructions(&H49) = INS_EOR: ClockTicks(&H49) = 3
            AddressingModes(&H4D) = ADR_ABS: Instructions(&H4D) = INS_EOR: ClockTicks(&H4D) = 4
            AddressingModes(&H51) = ADR_PII: Instructions(&H51) = INS_EOR: ClockTicks(&H51) = 5
            AddressingModes(&H52) = ADR_IZP: Instructions(&H52) = INS_EOR: ClockTicks(&H52) = 3
            AddressingModes(&H55) = ADR_ZPX: Instructions(&H55) = INS_EOR: ClockTicks(&H55) = 4
            AddressingModes(&H59) = ADR_INY: Instructions(&H59) = INS_EOR: ClockTicks(&H59) = 4
            AddressingModes(&H5D) = ADR_INX: Instructions(&H5D) = INS_EOR: ClockTicks(&H5D) = 4
            'INA
            AddressingModes(&H1A) = ADR_IMP: Instructions(&H1A) = INS_INA: ClockTicks(&H1A) = 2
            'INC
            AddressingModes(&HE6) = ADR_ZP: Instructions(&HE6) = INS_INC: ClockTicks(&HE6) = 5
            AddressingModes(&HEE) = ADR_ABS: Instructions(&HEE) = INS_INC: ClockTicks(&HEE) = 6
            AddressingModes(&HF6) = ADR_ZPX: Instructions(&HF6) = INS_INC: ClockTicks(&HF6) = 6
            AddressingModes(&HFE) = ADR_INX: Instructions(&HFE) = INS_INC: ClockTicks(&HFE) = 7
            'INX
            AddressingModes(&HE8) = ADR_IMP: Instructions(&HE8) = INS_INX: ClockTicks(&HE8) = 2
            'INY
            AddressingModes(&HC8) = ADR_IMP: Instructions(&HC8) = INS_INY: ClockTicks(&HC8) = 2
            'JMP
            AddressingModes(&H4C) = ADR_ABS: Instructions(&H4C) = INS_JMP: ClockTicks(&H4C) = 3
            AddressingModes(&H6C) = ADR_IND: Instructions(&H6C) = INS_JMP: ClockTicks(&H6C) = 5
            'JSR
            AddressingModes(&H20) = ADR_IMP: Instructions(&H20) = INS_JSR: ClockTicks(&H20) = 6
            'LDA
            AddressingModes(&HA1) = ADR_PIX: Instructions(&HA1) = INS_LDA: ClockTicks(&HA1) = 6
            AddressingModes(&HA5) = ADR_ZP: Instructions(&HA5) = INS_LDA: ClockTicks(&HA5) = 3
            AddressingModes(&HA9) = ADR_IMM: Instructions(&HA9) = INS_LDA: ClockTicks(&HA9) = 3
            AddressingModes(&HAD) = ADR_ABS: Instructions(&HAD) = INS_LDA: ClockTicks(&HAD) = 6
            AddressingModes(&HB1) = ADR_PII: Instructions(&HB1) = INS_LDA: ClockTicks(&HB1) = 5
            AddressingModes(&HB2) = ADR_IZP: Instructions(&HB2) = INS_LDA: ClockTicks(&HB2) = 3
            AddressingModes(&HB5) = ADR_ZPX: Instructions(&HB5) = INS_LDA: ClockTicks(&HB5) = 4
            AddressingModes(&HB9) = ADR_INY: Instructions(&HB9) = INS_LDA: ClockTicks(&HB9) = 4
            AddressingModes(&HBD) = ADR_INX: Instructions(&HBD) = INS_LDA: ClockTicks(&HBD) = 4
            'LDX
            AddressingModes(&HA2) = ADR_IMM: Instructions(&HA2) = INS_LDX: ClockTicks(&HA2) = 3
            AddressingModes(&HA6) = ADR_ZP: Instructions(&HA6) = INS_LDX: ClockTicks(&HA6) = 3
            AddressingModes(&HAE) = ADR_ABS: Instructions(&HAE) = INS_LDX: ClockTicks(&HAE) = 4
            AddressingModes(&HB6) = ADR_ZPY: Instructions(&HB6) = INS_LDX: ClockTicks(&HB6) = 4
            AddressingModes(&HBE) = ADR_INY: Instructions(&HBE) = INS_LDX: ClockTicks(&HBE) = 4
            'LDY
            AddressingModes(&HA0) = ADR_IMM: Instructions(&HA0) = INS_LDY: ClockTicks(&HA0) = 3
            AddressingModes(&HA4) = ADR_ZP: Instructions(&HA4) = INS_LDY: ClockTicks(&HA4) = 3
            AddressingModes(&HAC) = ADR_ABS: Instructions(&HAC) = INS_LDY: ClockTicks(&HAC) = 4
            AddressingModes(&HB4) = ADR_ZPX: Instructions(&HB4) = INS_LDY: ClockTicks(&HB4) = 4
            AddressingModes(&HBC) = ADR_INX: Instructions(&HBC) = INS_LDY: ClockTicks(&HBC) = 4
            'LSR
            AddressingModes(&H46) = ADR_ZP: Instructions(&H46) = INS_LSR: ClockTicks(&H46) = 5
            AddressingModes(&H4A) = ADR_ACC: Instructions(&H4A) = INS_LSR: ClockTicks(&H4A) = 2
            AddressingModes(&H4E) = ADR_ABS: Instructions(&H4E) = INS_LSR: ClockTicks(&H4E) = 6
            AddressingModes(&H56) = ADR_ZPX: Instructions(&H56) = INS_LSR: ClockTicks(&H56) = 6
            AddressingModes(&H5E) = ADR_INX: Instructions(&H5E) = INS_LSR: ClockTicks(&H5E) = 7
            'NOP
            AddressingModes(&HEA) = ADR_IMP: Instructions(&HEA) = INS_NOP: ClockTicks(&HEA) = 2
            'ORA
            AddressingModes(&H1) = ADR_PIX: Instructions(&H1) = INS_ORA: ClockTicks(&H1) = 6
            AddressingModes(&H5) = ADR_ZP: Instructions(&H5) = INS_ORA: ClockTicks(&H5) = 3
            AddressingModes(&H9) = ADR_IMM: Instructions(&H9) = INS_ORA: ClockTicks(&H9) = 3
            AddressingModes(&HD) = ADR_ABS: Instructions(&HD) = INS_ORA: ClockTicks(&HD) = 4
            AddressingModes(&H11) = ADR_PII: Instructions(&H11) = INS_ORA: ClockTicks(&H11) = 5
            AddressingModes(&H12) = ADR_IZP: Instructions(&H12) = INS_ORA: ClockTicks(&H12) = 3
            AddressingModes(&H15) = ADR_ZPX: Instructions(&H15) = INS_ORA: ClockTicks(&H15) = 4
            AddressingModes(&H19) = ADR_INY: Instructions(&H19) = INS_ORA: ClockTicks(&H19) = 4
            AddressingModes(&H1D) = ADR_INX: Instructions(&H1D) = INS_ORA: ClockTicks(&H1D) = 4
            'PHA
            AddressingModes(&H48) = ADR_IMP: Instructions(&H48) = INS_PHA: ClockTicks(&H48) = 3
            'PHP
            AddressingModes(&H8) = ADR_IMP: Instructions(&H8) = INS_PHP: ClockTicks(&H8) = 3
            'PHX
            AddressingModes(&HDA) = ADR_IMP: Instructions(&HDA) = INS_PHX: ClockTicks(&HDA) = 3
            'PHY
            AddressingModes(&H5A) = ADR_IMP: Instructions(&H5A) = INS_PHY: ClockTicks(&H5A) = 3
            'PLA
            AddressingModes(&H68) = ADR_IMP: Instructions(&H68) = INS_PLA: ClockTicks(&H68) = 4
            'PLP
            AddressingModes(&H28) = ADR_IMP: Instructions(&H28) = INS_PLP: ClockTicks(&H28) = 4
            'PLX
            AddressingModes(&HFA) = ADR_IMP: Instructions(&HFA) = INS_PLX: ClockTicks(&HFA) = 4
            'PLY
            AddressingModes(&H7A) = ADR_IMP: Instructions(&H7A) = INS_PLY: ClockTicks(&H7A) = 4
            'ROL
            AddressingModes(&H26) = ADR_ZP: Instructions(&H26) = INS_ROL: ClockTicks(&H26) = 5
            AddressingModes(&H2A) = ADR_ACC: Instructions(&H2A) = INS_ROL: ClockTicks(&H2A) = 2
            AddressingModes(&H2E) = ADR_ABS: Instructions(&H2E) = INS_ROL: ClockTicks(&H2E) = 6
            AddressingModes(&H36) = ADR_ZPX: Instructions(&H36) = INS_ROL: ClockTicks(&H36) = 6
            AddressingModes(&H3E) = ADR_INX: Instructions(&H3E) = INS_ROL: ClockTicks(&H3E) = 7
            'ROR
            AddressingModes(&H66) = ADR_ZP: Instructions(&H66) = INS_ROR: ClockTicks(&H66) = 5
            AddressingModes(&H6A) = ADR_ACC: Instructions(&H2A) = INS_ROR: ClockTicks(&H2A) = 2
            AddressingModes(&H6E) = ADR_ABS: Instructions(&H6E) = INS_ROR: ClockTicks(&H6E) = 6
            AddressingModes(&H76) = ADR_ZPX: Instructions(&H76) = INS_ROR: ClockTicks(&H76) = 6
            AddressingModes(&H7E) = ADR_INX: Instructions(&H7E) = INS_ROR: ClockTicks(&H7E) = 7
            'RTI
            AddressingModes(&H40) = ADR_IMP: Instructions(&H40) = INS_RTI: ClockTicks(&H40) = 6
            'RTS
            AddressingModes(&H60) = ADR_IMP: Instructions(&H60) = INS_RTS: ClockTicks(&H60) = 6
            'SBC
            AddressingModes(&HE1) = ADR_PIX: Instructions(&HE1) = INS_SBC: ClockTicks(&HE1) = 6
            AddressingModes(&HE5) = ADR_ZP: Instructions(&HE5) = INS_SBC: ClockTicks(&HE5) = 3
            AddressingModes(&HE9) = ADR_IMM: Instructions(&HE9) = INS_SBC: ClockTicks(&HE9) = 3
            AddressingModes(&HED) = ADR_ABS: Instructions(&HED) = INS_SBC: ClockTicks(&HED) = 4
            AddressingModes(&HF1) = ADR_PII: Instructions(&HF1) = INS_SBC: ClockTicks(&HF1) = 5
            AddressingModes(&HF2) = ADR_IZP: Instructions(&HF2) = INS_SBC: ClockTicks(&HF2) = 3
            AddressingModes(&HF5) = ADR_ZPX: Instructions(&HF5) = INS_SBC: ClockTicks(&HF5) = 4
            AddressingModes(&HF9) = ADR_INY: Instructions(&HF9) = INS_SBC: ClockTicks(&HF9) = 4
            AddressingModes(&HFD) = ADR_INX: Instructions(&HFD) = INS_SBC: ClockTicks(&HFD) = 4
            'SEC
            AddressingModes(&H38) = ADR_IMP: Instructions(&H38) = INS_SEC: ClockTicks(&H38) = 2
            'SED
            AddressingModes(&HF8) = ADR_IMP: Instructions(&HF8) = INS_SED: ClockTicks(&HF8) = 2
            'SEI
            AddressingModes(&H78) = ADR_IMP: Instructions(&H78) = INS_SEI: ClockTicks(&H78) = 2
            'STA
            AddressingModes(&H81) = ADR_PIX: Instructions(&H81) = INS_STA: ClockTicks(&H81) = 6
            AddressingModes(&H85) = ADR_ZP: Instructions(&H85) = INS_STA: ClockTicks(&H85) = 2
            AddressingModes(&H8D) = ADR_ABS: Instructions(&H8D) = INS_STA: ClockTicks(&H8D) = 4
            AddressingModes(&H91) = ADR_PII: Instructions(&H91) = INS_STA: ClockTicks(&H91) = 6
            AddressingModes(&H92) = ADR_IZP: Instructions(&H92) = INS_STA: ClockTicks(&H92) = 3
            AddressingModes(&H95) = ADR_ZPX: Instructions(&H95) = INS_STA: ClockTicks(&H95) = 4
            AddressingModes(&H99) = ADR_INY: Instructions(&H99) = INS_STA: ClockTicks(&H99) = 5
            AddressingModes(&H9D) = ADR_INX: Instructions(&H9D) = INS_STA: ClockTicks(&H9D) = 5
            'STX
            AddressingModes(&H86) = ADR_ZP: Instructions(&H86) = INS_STX: ClockTicks(&H86) = 2
            AddressingModes(&H8E) = ADR_ABS: Instructions(&H8E) = INS_STX: ClockTicks(&H8E) = 4
            AddressingModes(&H96) = ADR_ZPY: Instructions(&H96) = INS_STX: ClockTicks(&H96) = 4
            'STY
            AddressingModes(&H84) = ADR_ZP: Instructions(&H84) = INS_STY: ClockTicks(&H84) = 2
            AddressingModes(&H8C) = ADR_ABS: Instructions(&H8C) = INS_STY: ClockTicks(&H8C) = 4
            AddressingModes(&H94) = ADR_ZPX: Instructions(&H94) = INS_STY: ClockTicks(&H94) = 4
            'STZ
            AddressingModes(&H64) = ADR_ZP: Instructions(&H64) = INS_STZ: ClockTicks(&H64) = 4
            AddressingModes(&H74) = ADR_ZPX: Instructions(&H74) = INS_STZ: ClockTicks(&H74) = 4
            AddressingModes(&H9C) = ADR_ABS: Instructions(&H9C) = INS_STZ: ClockTicks(&H9C) = 4
            AddressingModes(&H9E) = ADR_INX: Instructions(&H9E) = INS_STZ: ClockTicks(&H9E) = 4
            'TAX
            AddressingModes(&HAA) = ADR_IMP: Instructions(&HAA) = INS_TAX: ClockTicks(&HAA) = 2
            'TAY
            AddressingModes(&HA8) = ADR_IMP: Instructions(&HA8) = INS_TAY: ClockTicks(&HA8) = 2
            'TSX
            AddressingModes(&HBA) = ADR_IMP: Instructions(&HBA) = INS_TSX: ClockTicks(&HBA) = 2
            'TXA
            AddressingModes(&H8A) = ADR_IMP: Instructions(&H8A) = INS_TXA: ClockTicks(&H8A) = 2
            'TXS
            AddressingModes(&H9A) = ADR_IMP: Instructions(&H9A) = INS_TXS: ClockTicks(&H9A) = 2
            'TYA
            AddressingModes(&H98) = ADR_IMP: Instructions(&H98) = INS_TYA: ClockTicks(&H98) = 2
            'TRB
            AddressingModes(&H14) = ADR_ZP: Instructions(&H14) = INS_TRB: ClockTicks(&H14) = 3
            AddressingModes(&H1C) = ADR_ABS: Instructions(&H1C) = INS_TRB: ClockTicks(&H1C) = 4
            'TSB
            AddressingModes(&H4) = ADR_ZP: Instructions(&H4) = INS_TSB: ClockTicks(&H4) = 3
            AddressingModes(&HC) = ADR_ABS: Instructions(&HC) = INS_TSB: ClockTicks(&HC) = 4
        Case CPU_M65SC02 'Centipede, Millipede, etc.
            'ADC
            AddressingModes(&H61) = ADR_PIX: Instructions(&H61) = INS_ADC: ClockTicks(&H61) = 6
            AddressingModes(&H65) = ADR_ZP: Instructions(&H65) = INS_ADC: ClockTicks(&H65) = 3
            AddressingModes(&H69) = ADR_IMM: Instructions(&H69) = INS_ADC: ClockTicks(&H69) = 3
            AddressingModes(&H6D) = ADR_ABS: Instructions(&H6D) = INS_ADC: ClockTicks(&H6D) = 4
            AddressingModes(&H71) = ADR_PII: Instructions(&H71) = INS_ADC: ClockTicks(&H71) = 5
            AddressingModes(&H72) = ADR_IZP: Instructions(&H72) = INS_ADC: ClockTicks(&H72) = 3
            AddressingModes(&H75) = ADR_ZPX: Instructions(&H75) = INS_ADC: ClockTicks(&H75) = 4
            AddressingModes(&H79) = ADR_INY: Instructions(&H79) = INS_ADC: ClockTicks(&H79) = 4
            AddressingModes(&H7D) = ADR_INX: Instructions(&H7D) = INS_ADC: ClockTicks(&H7D) = 4
            'AND
            AddressingModes(&H21) = ADR_PIX: Instructions(&H21) = INS_AND: ClockTicks(&H21) = 6
            AddressingModes(&H25) = ADR_ZP: Instructions(&H25) = INS_AND: ClockTicks(&H25) = 3
            AddressingModes(&H29) = ADR_IMM: Instructions(&H29) = INS_AND: ClockTicks(&H29) = 3
            AddressingModes(&H2D) = ADR_ABS: Instructions(&H2D) = INS_AND: ClockTicks(&H2D) = 4
            AddressingModes(&H31) = ADR_PII: Instructions(&H31) = INS_AND: ClockTicks(&H31) = 5
            AddressingModes(&H32) = ADR_IZP: Instructions(&H32) = INS_AND: ClockTicks(&H32) = 3
            AddressingModes(&H35) = ADR_ZPX: Instructions(&H35) = INS_AND: ClockTicks(&H35) = 4
            AddressingModes(&H39) = ADR_INY: Instructions(&H39) = INS_AND: ClockTicks(&H39) = 4
            AddressingModes(&H3D) = ADR_INX: Instructions(&H3D) = INS_AND: ClockTicks(&H3D) = 4
            'ASL
            AddressingModes(&H6) = ADR_ZP: Instructions(&H6) = INS_ASL: ClockTicks(&H6) = 5
            AddressingModes(&HA) = ADR_ACC: Instructions(&HA) = INS_ASL: ClockTicks(&HA) = 2
            AddressingModes(&HE) = ADR_ABS: Instructions(&HE) = INS_ASL: ClockTicks(&HE) = 6
            AddressingModes(&H16) = ADR_ZPX: Instructions(&H16) = INS_ASL: ClockTicks(&H16) = 6
            AddressingModes(&H1E) = ADR_INX: Instructions(&H1E) = INS_ASL: ClockTicks(&H1E) = 7
            'BCC
            AddressingModes(&H90) = ADR_IMP: Instructions(&H90) = INS_BCC: ClockTicks(&H90) = 2
            'BCS
            AddressingModes(&HB0) = ADR_IMP: Instructions(&HB0) = INS_BCS: ClockTicks(&HB0) = 2
            'BEQ
            AddressingModes(&HF0) = ADR_IMP: Instructions(&HF0) = INS_BEQ: ClockTicks(&HF0) = 2
            'BIT
            AddressingModes(&H24) = ADR_ZP: Instructions(&H24) = INS_BIT: ClockTicks(&H24) = 3
            AddressingModes(&H2C) = ADR_ABS: Instructions(&H2C) = INS_BIT: ClockTicks(&H2C) = 4
            AddressingModes(&H34) = ADR_ZPX: Instructions(&H34) = INS_BIT: ClockTicks(&H34) = 4
            AddressingModes(&H3C) = ADR_INX: Instructions(&H3C) = INS_BIT: ClockTicks(&H3C) = 4
            AddressingModes(&H89) = ADR_IMM: Instructions(&H89) = INS_BIT: ClockTicks(&H89) = 2
            'BMI
            AddressingModes(&H30) = ADR_IMP: Instructions(&H30) = INS_BMI: ClockTicks(&H30) = 2
            'BNE
            AddressingModes(&HD0) = ADR_IMP: Instructions(&HD0) = INS_BNE: ClockTicks(&HD0) = 2
            'BPL
            AddressingModes(&H10) = ADR_IMP: Instructions(&H10) = INS_BPL: ClockTicks(&H10) = 2
            'BRA
            AddressingModes(&H80) = ADR_IMP: Instructions(&H80) = INS_BRA: ClockTicks(&H80) = 2
            'BRK
            AddressingModes(&H0) = ADR_IMP: Instructions(&H0) = INS_BRK: ClockTicks(&H0) = 7
            'BVC
            AddressingModes(&H50) = ADR_IMP: Instructions(&H50) = INS_BVC: ClockTicks(&H50) = 2
            'BVS
            AddressingModes(&H70) = ADR_IMP: Instructions(&H70) = INS_BVS: ClockTicks(&H70) = 2
            'CLC
            AddressingModes(&H18) = ADR_IMP: Instructions(&H18) = INS_CLC: ClockTicks(&H18) = 2
            'CLD
            AddressingModes(&HD8) = ADR_IMP: Instructions(&HD8) = INS_CLD: ClockTicks(&HD8) = 2
            'CLI
            AddressingModes(&H58) = ADR_IMP: Instructions(&H58) = INS_CLI: ClockTicks(&H58) = 2
            'CLV
            AddressingModes(&HB8) = ADR_IMP: Instructions(&HB8) = INS_CLV: ClockTicks(&HB8) = 2
            'CMP
            AddressingModes(&HC1) = ADR_PIX: Instructions(&HC1) = INS_CMP: ClockTicks(&HC1) = 6
            AddressingModes(&HC5) = ADR_ZP: Instructions(&HC5) = INS_CMP: ClockTicks(&HC5) = 3
            AddressingModes(&HC9) = ADR_IMM: Instructions(&HC9) = INS_CMP: ClockTicks(&HC9) = 3
            AddressingModes(&HCD) = ADR_ABS: Instructions(&HCD) = INS_CMP: ClockTicks(&HCD) = 4
            AddressingModes(&HD1) = ADR_PII: Instructions(&HD1) = INS_CMP: ClockTicks(&HD1) = 5
            AddressingModes(&HD2) = ADR_IZP: Instructions(&HD2) = INS_CMP: ClockTicks(&HD2) = 3
            AddressingModes(&HD5) = ADR_ZPX: Instructions(&HD5) = INS_CMP: ClockTicks(&HD5) = 4
            AddressingModes(&HD9) = ADR_INY: Instructions(&HD9) = INS_CMP: ClockTicks(&HD9) = 4
            'CPX
            AddressingModes(&HE0) = ADR_IMM: Instructions(&HE0) = INS_CPX: ClockTicks(&HE0) = 3
            AddressingModes(&HE4) = ADR_ZP: Instructions(&HE4) = INS_CPX: ClockTicks(&HE4) = 3
            AddressingModes(&HEC) = ADR_ABS: Instructions(&HEC) = INS_CPX: ClockTicks(&HEC) = 4
            'CPY
            AddressingModes(&HC0) = ADR_IMM: Instructions(&HC0) = INS_CPY: ClockTicks(&HC0) = 3
            AddressingModes(&HC4) = ADR_ZP: Instructions(&HC4) = INS_CPY: ClockTicks(&HC4) = 3
            AddressingModes(&HCC) = ADR_ABS: Instructions(&HCC) = INS_CPY: ClockTicks(&HCC) = 4
            'DEA
            AddressingModes(&H3A) = ADR_IMP: Instructions(&H3A) = INS_DEA: ClockTicks(&H3A) = 2
            'DEC
            AddressingModes(&HC6) = ADR_ZP: Instructions(&HC6) = INS_DEC: ClockTicks(&HC6) = 5
            AddressingModes(&HCE) = ADR_ABS: Instructions(&HCE) = INS_DEC: ClockTicks(&HCE) = 6
            AddressingModes(&HD6) = ADR_ZPX: Instructions(&HD6) = INS_DEC: ClockTicks(&HD6) = 6
            AddressingModes(&HDE) = ADR_INX: Instructions(&HDE) = INS_DEC: ClockTicks(&HDE) = 7
            'DEX
            AddressingModes(&HCA) = ADR_IMP: Instructions(&HCA) = INS_DEX: ClockTicks(&HCA) = 2
            'DEY
            AddressingModes(&H88) = ADR_IMP: Instructions(&H88) = INS_DEY: ClockTicks(&H88) = 2
            'EOR
            AddressingModes(&H41) = ADR_PIX: Instructions(&H41) = INS_EOR: ClockTicks(&H41) = 6
            AddressingModes(&H45) = ADR_ZP: Instructions(&H45) = INS_EOR: ClockTicks(&H45) = 3
            AddressingModes(&H49) = ADR_IMM: Instructions(&H49) = INS_EOR: ClockTicks(&H49) = 3
            AddressingModes(&H4D) = ADR_ABS: Instructions(&H4D) = INS_EOR: ClockTicks(&H4D) = 4
            AddressingModes(&H51) = ADR_PII: Instructions(&H51) = INS_EOR: ClockTicks(&H51) = 5
            AddressingModes(&H52) = ADR_IZP: Instructions(&H52) = INS_EOR: ClockTicks(&H52) = 3
            AddressingModes(&H55) = ADR_ZPX: Instructions(&H55) = INS_EOR: ClockTicks(&H55) = 4
            AddressingModes(&H59) = ADR_INY: Instructions(&H59) = INS_EOR: ClockTicks(&H59) = 4
            AddressingModes(&H5D) = ADR_INX: Instructions(&H5D) = INS_EOR: ClockTicks(&H5D) = 4
            'INA
            AddressingModes(&H1A) = ADR_IMP: Instructions(&H1A) = INS_INA: ClockTicks(&H1A) = 2
            'INC
            AddressingModes(&HE6) = ADR_ZP: Instructions(&HE6) = INS_INC: ClockTicks(&HE6) = 5
            AddressingModes(&HEE) = ADR_ABS: Instructions(&HEE) = INS_INC: ClockTicks(&HEE) = 6
            AddressingModes(&HF6) = ADR_ZPX: Instructions(&HF6) = INS_INC: ClockTicks(&HF6) = 6
            AddressingModes(&HFE) = ADR_INX: Instructions(&HFE) = INS_INC: ClockTicks(&HFE) = 7
            'INX
            AddressingModes(&HE8) = ADR_IMP: Instructions(&HE8) = INS_INX: ClockTicks(&HE8) = 2
            'INY
            AddressingModes(&HC8) = ADR_IMP: Instructions(&HC8) = INS_INY: ClockTicks(&HC8) = 2
            'JMP
            AddressingModes(&H4C) = ADR_ABS: Instructions(&H4C) = INS_JMP: ClockTicks(&H4C) = 3
            AddressingModes(&H6C) = ADR_IND: Instructions(&H6C) = INS_JMP: ClockTicks(&H6C) = 5
            'JSR
            AddressingModes(&H20) = ADR_IMP: Instructions(&H20) = INS_JSR: ClockTicks(&H20) = 6
            'LDA
            AddressingModes(&HA1) = ADR_PIX: Instructions(&HA1) = INS_LDA: ClockTicks(&HA1) = 6
            AddressingModes(&HA5) = ADR_ZP: Instructions(&HA5) = INS_LDA: ClockTicks(&HA5) = 3
            AddressingModes(&HA9) = ADR_IMM: Instructions(&HA9) = INS_LDA: ClockTicks(&HA9) = 3
            AddressingModes(&HAD) = ADR_ABS: Instructions(&HAD) = INS_LDA: ClockTicks(&HAD) = 6
            AddressingModes(&HB1) = ADR_PII: Instructions(&HB1) = INS_LDA: ClockTicks(&HB1) = 5
            AddressingModes(&HB2) = ADR_IZP: Instructions(&HB2) = INS_LDA: ClockTicks(&HB2) = 3
            AddressingModes(&HB5) = ADR_ZPX: Instructions(&HB5) = INS_LDA: ClockTicks(&HB5) = 4
            AddressingModes(&HB9) = ADR_INY: Instructions(&HB9) = INS_LDA: ClockTicks(&HB9) = 4
            AddressingModes(&HBD) = ADR_INX: Instructions(&HBD) = INS_LDA: ClockTicks(&HBD) = 4
            'LDX
            AddressingModes(&HA2) = ADR_IMM: Instructions(&HA2) = INS_LDX: ClockTicks(&HA2) = 3
            AddressingModes(&HA6) = ADR_ZP: Instructions(&HA6) = INS_LDX: ClockTicks(&HA6) = 3
            AddressingModes(&HAE) = ADR_ABS: Instructions(&HAE) = INS_LDX: ClockTicks(&HAE) = 4
            AddressingModes(&HB6) = ADR_ZPY: Instructions(&HB6) = INS_LDX: ClockTicks(&HB6) = 4
            AddressingModes(&HBE) = ADR_INY: Instructions(&HBE) = INS_LDX: ClockTicks(&HBE) = 4
            'LDY
            AddressingModes(&HA0) = ADR_IMM: Instructions(&HA0) = INS_LDY: ClockTicks(&HA0) = 3
            AddressingModes(&HA4) = ADR_ZP: Instructions(&HA4) = INS_LDY: ClockTicks(&HA4) = 3
            AddressingModes(&HAC) = ADR_ABS: Instructions(&HAC) = INS_LDY: ClockTicks(&HAC) = 4
            AddressingModes(&HB4) = ADR_ZPX: Instructions(&HB4) = INS_LDY: ClockTicks(&HB4) = 4
            AddressingModes(&HBC) = ADR_INX: Instructions(&HBC) = INS_LDY: ClockTicks(&HBC) = 4
            'LSR
            AddressingModes(&H46) = ADR_ZP: Instructions(&H46) = INS_LSR: ClockTicks(&H46) = 5
            AddressingModes(&H4A) = ADR_ACC: Instructions(&H4A) = INS_LSR: ClockTicks(&H4A) = 2
            AddressingModes(&H4E) = ADR_ABS: Instructions(&H4E) = INS_LSR: ClockTicks(&H4E) = 6
            AddressingModes(&H56) = ADR_ZPX: Instructions(&H56) = INS_LSR: ClockTicks(&H56) = 6
            AddressingModes(&H5E) = ADR_INX: Instructions(&H5E) = INS_LSR: ClockTicks(&H5E) = 7
            'NOP
            AddressingModes(&HEA) = ADR_IMP: Instructions(&HEA) = INS_NOP: ClockTicks(&HEA) = 2
            'ORA
            AddressingModes(&H1) = ADR_PIX: Instructions(&H1) = INS_ORA: ClockTicks(&H1) = 6
            AddressingModes(&H5) = ADR_ZP: Instructions(&H5) = INS_ORA: ClockTicks(&H5) = 3
            AddressingModes(&H9) = ADR_IMM: Instructions(&H9) = INS_ORA: ClockTicks(&H9) = 3
            AddressingModes(&HD) = ADR_ABS: Instructions(&HD) = INS_ORA: ClockTicks(&HD) = 4
            AddressingModes(&H11) = ADR_PII: Instructions(&H11) = INS_ORA: ClockTicks(&H11) = 5
            AddressingModes(&H12) = ADR_IZP: Instructions(&H12) = INS_ORA: ClockTicks(&H12) = 3
            AddressingModes(&H15) = ADR_ZPX: Instructions(&H15) = INS_ORA: ClockTicks(&H15) = 4
            AddressingModes(&H19) = ADR_INY: Instructions(&H19) = INS_ORA: ClockTicks(&H19) = 4
            AddressingModes(&H1D) = ADR_INX: Instructions(&H1D) = INS_ORA: ClockTicks(&H1D) = 4
            'PHA
            AddressingModes(&H48) = ADR_IMP: Instructions(&H48) = INS_PHA: ClockTicks(&H48) = 3
            'PHP
            AddressingModes(&H8) = ADR_IMP: Instructions(&H8) = INS_PHP: ClockTicks(&H8) = 3
            'PHX
            AddressingModes(&HDA) = ADR_IMP: Instructions(&HDA) = INS_PHX: ClockTicks(&HDA) = 3
            'PHY
            AddressingModes(&H5A) = ADR_IMP: Instructions(&H5A) = INS_PHY: ClockTicks(&H5A) = 3
            'PLA
            AddressingModes(&H68) = ADR_IMP: Instructions(&H68) = INS_PLA: ClockTicks(&H68) = 4
            'PLP
            AddressingModes(&H28) = ADR_IMP: Instructions(&H28) = INS_PLP: ClockTicks(&H28) = 4
            'PLX
            AddressingModes(&HFA) = ADR_IMP: Instructions(&HFA) = INS_PLX: ClockTicks(&HFA) = 4
            'PLY
            AddressingModes(&H7A) = ADR_IMP: Instructions(&H7A) = INS_PLY: ClockTicks(&H7A) = 4
            'ROL
            AddressingModes(&H26) = ADR_ZP: Instructions(&H26) = INS_ROL: ClockTicks(&H26) = 5
            AddressingModes(&H2A) = ADR_ACC: Instructions(&H2A) = INS_ROL: ClockTicks(&H2A) = 2
            AddressingModes(&H2E) = ADR_ABS: Instructions(&H2E) = INS_ROL: ClockTicks(&H2E) = 6
            AddressingModes(&H36) = ADR_ZPX: Instructions(&H36) = INS_ROL: ClockTicks(&H36) = 6
            AddressingModes(&H3E) = ADR_INX: Instructions(&H3E) = INS_ROL: ClockTicks(&H3E) = 7
            'ROR
            AddressingModes(&H66) = ADR_ZP: Instructions(&H66) = INS_ROR: ClockTicks(&H66) = 5
            AddressingModes(&H6A) = ADR_ACC: Instructions(&H2A) = INS_ROR: ClockTicks(&H2A) = 2
            AddressingModes(&H6E) = ADR_ABS: Instructions(&H6E) = INS_ROR: ClockTicks(&H6E) = 6
            AddressingModes(&H76) = ADR_ZPX: Instructions(&H76) = INS_ROR: ClockTicks(&H76) = 6
            AddressingModes(&H7E) = ADR_INX: Instructions(&H7E) = INS_ROR: ClockTicks(&H7E) = 7
            'RTI
            AddressingModes(&H40) = ADR_IMP: Instructions(&H40) = INS_RTI: ClockTicks(&H40) = 6
            'RTS
            AddressingModes(&H60) = ADR_IMP: Instructions(&H60) = INS_RTS: ClockTicks(&H60) = 6
            'SBC
            AddressingModes(&HE1) = ADR_PIX: Instructions(&HE1) = INS_SBC: ClockTicks(&HE1) = 6
            AddressingModes(&HE5) = ADR_ZP: Instructions(&HE5) = INS_SBC: ClockTicks(&HE5) = 3
            AddressingModes(&HE9) = ADR_IMM: Instructions(&HE9) = INS_SBC: ClockTicks(&HE9) = 3
            AddressingModes(&HED) = ADR_ABS: Instructions(&HED) = INS_SBC: ClockTicks(&HED) = 4
            AddressingModes(&HF1) = ADR_PII: Instructions(&HF1) = INS_SBC: ClockTicks(&HF1) = 5
            AddressingModes(&HF2) = ADR_IZP: Instructions(&HF2) = INS_SBC: ClockTicks(&HF2) = 3
            AddressingModes(&HF5) = ADR_ZPX: Instructions(&HF5) = INS_SBC: ClockTicks(&HF5) = 4
            AddressingModes(&HF9) = ADR_INY: Instructions(&HF9) = INS_SBC: ClockTicks(&HF9) = 4
            AddressingModes(&HFD) = ADR_INX: Instructions(&HFD) = INS_SBC: ClockTicks(&HFD) = 4
            'SEC
            AddressingModes(&H38) = ADR_IMP: Instructions(&H38) = INS_SEC: ClockTicks(&H38) = 2
            'SED
            AddressingModes(&HF8) = ADR_IMP: Instructions(&HF8) = INS_SED: ClockTicks(&HF8) = 2
            'SEI
            AddressingModes(&H78) = ADR_IMP: Instructions(&H78) = INS_SEI: ClockTicks(&H78) = 2
            'STA
            AddressingModes(&H81) = ADR_PIX: Instructions(&H81) = INS_STA: ClockTicks(&H81) = 6
            AddressingModes(&H85) = ADR_ZP: Instructions(&H85) = INS_STA: ClockTicks(&H85) = 2
            AddressingModes(&H8D) = ADR_ABS: Instructions(&H8D) = INS_STA: ClockTicks(&H8D) = 4
            AddressingModes(&H91) = ADR_PII: Instructions(&H91) = INS_STA: ClockTicks(&H91) = 6
            AddressingModes(&H92) = ADR_IZP: Instructions(&H92) = INS_STA: ClockTicks(&H92) = 3
            AddressingModes(&H95) = ADR_ZPX: Instructions(&H95) = INS_STA: ClockTicks(&H95) = 4
            AddressingModes(&H99) = ADR_INY: Instructions(&H99) = INS_STA: ClockTicks(&H99) = 5
            AddressingModes(&H9D) = ADR_INX: Instructions(&H9D) = INS_STA: ClockTicks(&H9D) = 5
            'STX
            AddressingModes(&H86) = ADR_ZP: Instructions(&H86) = INS_STX: ClockTicks(&H86) = 2
            AddressingModes(&H8E) = ADR_ABS: Instructions(&H8E) = INS_STX: ClockTicks(&H8E) = 4
            AddressingModes(&H96) = ADR_ZPY: Instructions(&H96) = INS_STX: ClockTicks(&H96) = 4
            'STY
            AddressingModes(&H84) = ADR_ZP: Instructions(&H84) = INS_STY: ClockTicks(&H84) = 2
            AddressingModes(&H8C) = ADR_ABS: Instructions(&H8C) = INS_STY: ClockTicks(&H8C) = 4
            AddressingModes(&H94) = ADR_ZPX: Instructions(&H94) = INS_STY: ClockTicks(&H94) = 4
            'STZ
            AddressingModes(&H64) = ADR_ZP: Instructions(&H64) = INS_STZ: ClockTicks(&H64) = 4
            AddressingModes(&H74) = ADR_ZPX: Instructions(&H74) = INS_STZ: ClockTicks(&H74) = 4
            AddressingModes(&H9C) = ADR_ABS: Instructions(&H9C) = INS_STZ: ClockTicks(&H9C) = 4
            AddressingModes(&H9E) = ADR_INX: Instructions(&H9E) = INS_STZ: ClockTicks(&H9E) = 4
            'TAX
            AddressingModes(&HAA) = ADR_IMP: Instructions(&HAA) = INS_TAX: ClockTicks(&HAA) = 2
            'TAY
            AddressingModes(&HA8) = ADR_IMP: Instructions(&HA8) = INS_TAY: ClockTicks(&HA8) = 2
            'TSX
            AddressingModes(&HBA) = ADR_IMP: Instructions(&HBA) = INS_TSX: ClockTicks(&HBA) = 2
            'TXA
            AddressingModes(&H8A) = ADR_IMP: Instructions(&H8A) = INS_TXA: ClockTicks(&H8A) = 2
            'TXS
            AddressingModes(&H9A) = ADR_IMP: Instructions(&H9A) = INS_TXS: ClockTicks(&H9A) = 2
            'TYA
            AddressingModes(&H98) = ADR_IMP: Instructions(&H98) = INS_TYA: ClockTicks(&H98) = 2
            'TRB
            AddressingModes(&H14) = ADR_ZP: Instructions(&H14) = INS_TRB: ClockTicks(&H14) = 3
            AddressingModes(&H1C) = ADR_ABS: Instructions(&H1C) = INS_TRB: ClockTicks(&H1C) = 4
            'TSB
            AddressingModes(&H4) = ADR_ZP: Instructions(&H4) = INS_TSB: ClockTicks(&H4) = 3
            AddressingModes(&HC) = ADR_ABS: Instructions(&HC) = INS_TSB: ClockTicks(&HC) = 4
    End Select
    #If DEBUG_ON = 1 Then
        M6502_InitDebug
    #End If
End Sub
Private Function M6502_AddressMode(ByVal Mode As Byte) As Long
    Dim Helper As Long, help_hi As Long, tmp As Byte, tmp2 As Byte, tmp3 As Byte
    Dim l1 As Long, l2 As Long, l3 As Long
    Helper = 0
    tmp = 0
    tmp2 = 0
    tmp3 = 0
    help_hi = 0
    Select Case Mode
        Case ADR_ABS
            Helper = (Read6502(PC + 1) * &H100&) + Read6502(PC)
            PC = PC + 2
            #If DEBUG_ON Then
                AdrMsg = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
                Adr2 = ""
            #End If
        Case ADR_ACC
            Helper = A
            #If DEBUG_ON Then
                If Len(Hex$(A)) = 1 Then Adr2 = "$0" & Hex$(A) Else Adr2 = "$" & Hex$(A)
                AdrMsg = "A"
            #End If
        Case ADR_ERA
            Helper = 0
            'MsgBox "* Error in AddressMode(" & Hex$(opcode) & ");", 64, "M6502"
            #If DEBUG_ON Then
                AdrMsg = "ERR"
                Adr2 = ""
            #End If
        Case ADR_IMM
            Helper = PC
            PC = PC + 1
            #If DEBUG_ON Then
                AdrMsg = "#$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
                Adr2 = ""
            #End If
        Case ADR_IMP
            Helper = 0
            #If DEBUG_ON Then
                AdrMsg = ""
                Adr2 = ""
            #End If
        Case ADR_IND 'made it so the address mode can't jump page boundaries.
            help = (Read6502(PC + 1) * &H100&) + Read6502(PC)
            help_hi = (help And &HFF00&)
            tmp2 = (help And &HFF)
            tmp3 = Read6502(help_hi Or tmp2)
            tmp2 = (tmp2 + 1) And &HFF
            Helper = (Read6502(help_hi Or tmp2) * &H100&) Or tmp3
            PC = PC + 2
            #If DEBUG_ON Then
                AdrMsg = "($" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & ")"
                Adr2 = ""
            #End If
        Case ADR_INX
            Helper = (Read6502(PC + 1) * &H100&) + Read6502(PC)
            PC = PC + 2
            #If DEBUG_ON Then
                AdrMsg = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & ",X"
            #End If
            If ((Helper + X) > &HFFFF&) Then Ticks = Ticks - 1
            Helper = (Helper + X) And &HFFFF&
            #If DEBUG_ON Then
                Adr2 = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
            #End If
        Case ADR_INY
            Helper = (Read6502(PC + 1) * &H100&) + Read6502(PC)
            PC = PC + 2
            #If DEBUG_ON Then
                AdrMsg = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & ",Y"
            #End If
            If ((Helper + Y) > &HFFFF&) Then Ticks = Ticks - 1
            Helper = (Helper + Y) And &HFFFF&
            #If DEBUG_ON Then
                Adr2 = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
            #End If
        Case ADR_IZP
            tmp = Read6502(PC)
            PC = PC + 1
            tmp2 = Read6502(tmp)
            tmp = (tmp + 1) And &HFF
            Helper = ((Read6502(tmp) * &H100&) Or tmp2)
            #If DEBUG_ON Then
                AdrMsg = "($" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & ")"
                Adr2 = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
            #End If
        Case ADR_PII
            tmp = Read6502(PC)
            PC = PC + 1
            tmp2 = Read6502(tmp)
            tmp = (tmp + 1) And &HFF
            help = (Read6502(tmp) * &H100&) Or tmp2
            Helper = help
            #If DEBUG_ON Then
                AdrMsg = "($" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & "),Y"
            #End If
            Helper = (Helper + Y) And &HFFFF&
            #If DEBUG_ON Then
                Adr2 = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
            #End If
        Case ADR_PIX
            tmp = Read6502(PC)
            PC = PC + 1
            help = tmp
            help = (help + X) And &HFF
            tmp = help
            #If DEBUG_ON Then
                AdrMsg = "($" + String(4 - Len(Hex(tmp)), "0") + Hex$(tmp) & ",X)"
            #End If
            tmp2 = Read6502(tmp)
            tmp = (tmp + 1) And &HFF
            help = (Read6502(tmp) * &H100&) Or tmp2
            Helper = help
            #If DEBUG_ON Then
                Adr2 = "($" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & ")"
            #End If
        Case ADR_ZP
            tmp = Read6502(PC)
            PC = PC + 1
            Helper = CByte(tmp)
            #If DEBUG_ON Then
                AdrMsg = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
                Adr2 = ""
            #End If
        Case ADR_ZPX
            l1 = CByte(X)
            tmp = Read6502(PC)
            PC = PC + 1
            #If DEBUG_ON Then
                AdrMsg = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & ",X"
            #End If
            Helper = CByte((tmp + l1) And &HFF)
            #If DEBUG_ON Then
                Adr2 = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
            #End If
        Case ADR_ZPY
            l1 = CByte(Y)
            tmp = Read6502(PC)
            PC = PC + 1
            #If DEBUG_ON Then
                AdrMsg = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper) & ",Y"
            #End If
            Helper = CByte((tmp + l1) And &HFF)
            #If DEBUG_ON Then
                Adr2 = "$" + String(4 - Len(Hex(Helper)), "0") + Hex$(Helper)
            #End If
    End Select
    M6502_AddressMode = Helper
End Function
Public Sub M6502_Exec()
'exec6502()
'execute the inited amount of clock cycles.
temp = 0: temp2 = 0: help = 0

If CPUPaused = True Then
    Do Until CPUPaused = False
        DoEvents
    Loop
End If
If CPURunning = False Then
    Exit Sub
End If
  
  'TS: Implemented game randomizer
  TimerTicks = TimerTicks + 1
  If (TimerTicks And 7) = 1 Then
    gameImage(&H100A) = Int((255 * Rnd) + 1)
  End If
  
    opcode = Read6502(PC)
    PC = PC + 1

    Ticks = Ticks - ClockTicks(opcode)
    #If DEBUG_ON Then
        PrevOp = opcode
        PrevSavepc = savepc
        PrevOpcode = oMsg
        PrevAM = AdrMsg
    #End If
    
    #If DEBUG_ON Then
        oMsg = Ins(Instructions(opcode))
    #End If
    
    savepc = M6502_AddressMode(AddressingModes(opcode))
    Select Case Instructions(opcode)
        Case INS_ADC
            temp2 = (P And C_FLAG)
            temp = Read6502(savepc)
            help = A
            help = (help + temp + temp2)
            If (help > &HFF) Then
                P = P Or C_FLAG
            Else
                P = P And C_OFF
            End If
            help = help - &H100&
            If (Not ((A Xor temp) And &H80)) And ((A Xor help) And &H80) Then
                P = P Or V_FLAG
            Else
                P = P And V_OFF
            End If
            A = (help And &HFF)
            If (CPU_TYPE = CPU_M2A03) Then
            Else
                If (P And D_FLAG) Then
                    P = (P And C_OFF)
                    If ((A And &HF) > &H9) Then
                        A = (A + &H6) And &HFF
                    End If
                    If ((A And &HF0) > &H90) Then
                        A = (A + &H60) And &HFF
                        P = P Or C_FLAG
                    End If
                Else
                    Ticks = Ticks - 1
                End If
            End If
            M6502_SetFlags A
        Case INS_AND
            A = A And Read6502(savepc)
            M6502_SetFlags A
        Case INS_ASL
            If AddressingModes(opcode) = ADR_ACC Then
                help = (A * 2)
                A = (help And &HFF)
                If (help \ &H100&) Then
                    P = P Or C_FLAG
                Else
                    P = P And C_OFF
                End If
                M6502_SetFlags A
            Else
                temp = Read6502(savepc)
                Write6502 savepc, temp
                help = (temp * 2)
                temp = (help And &HFF)
                If (help \ &H100&) Then
                    P = P Or C_FLAG
                Else
                    P = P And C_OFF
                End If
                Write6502 savepc, temp
                M6502_SetFlags temp
            End If
        Case INS_BBR
            temp = (opcode \ &HF) - 1
            M6502_Branch ((Read6502(savepc) And pow2(temp)) = 0)
        Case INS_BBS
            temp = (opcode \ &HF) - 9
            M6502_Branch (Read6502(savepc) And pow2(temp))
        Case INS_BCC
            M6502_Branch ((P And C_FLAG) = 0)
        Case INS_BCS
            M6502_Branch (P And C_FLAG)
        Case INS_BEQ
            M6502_Branch (P And Z_FLAG)
        Case INS_BIT
            help = Read6502(savepc)
            If (help And A) Then
                P = P And Z_OFF
            Else
                P = P Or Z_FLAG
            End If
            P = ((P And &H3F) Or (help And &HC0))
        Case INS_BMI
            M6502_Branch (P And S_FLAG)
        Case INS_BNE
            M6502_Branch ((P And Z_FLAG) = 0)
        Case INS_BPL
            M6502_Branch ((P And S_FLAG) = 0)
        Case INS_BRA
            M6502_Branch True
        Case INS_BRK
            PC = PC + 1
            Write6502 (S + &H100&), (PC \ &H100&)
            S = (S - 1) And &HFF
            Write6502 (S + &H100&), (PC And &HFF)
            S = (S - 1) And &HFF
            Write6502 (S + &H100&), (P Or B_FLAG)
            S = (S - 1) And &HFF
            P = (P Or I_FLAG)
            PC = (Read6502(M6502IRQ + 1) * &H100&) Or Read6502(M6502IRQ)
        Case INS_BVC
            M6502_Branch ((P And V_FLAG) = 0)
        Case INS_BVS
            M6502_Branch (P And V_FLAG)
        Case INS_CLC
            P = (P And C_OFF)
        Case INS_CLD
            P = (P And D_OFF)
        Case INS_CLI
            P = (P And I_OFF)
        Case INS_CLV
            P = (P And V_OFF)
        Case INS_CMP
            temp = Read6502(savepc)
            help = (A + &H100& - temp)
            If (help And &H100&) Then
                P = P Or C_FLAG
            Else
                P = P And C_OFF
            End If
            temp = (help And &HFF)
            M6502_SetFlags temp
        Case INS_CPX
            temp = Read6502(savepc)
            help = (X + &H100& - temp)
            If (help > &HFF) Then
                P = P Or C_FLAG
            Else
                P = P And C_OFF
            End If
            temp = (help And &HFF)
            M6502_SetFlags temp
        Case INS_CPY
            temp = Read6502(savepc)
            help = (Y + &H100& - temp)
            If (help > &HFF) Then
                P = P Or C_FLAG
            Else
                P = P And C_OFF
            End If
            temp = (help And &HFF)
            M6502_SetFlags temp
        Case INS_DEA
            A = (A - 1) And &HFF
            M6502_SetFlags A
        Case INS_DEC
            temp = Read6502(savepc)
            Write6502 savepc, temp
            temp = (temp - 1) And &HFF
            M6502_SetFlags temp
            Write6502 savepc, temp
        Case INS_DEX
            X = (X - 1) And &HFF
            M6502_SetFlags X
        Case INS_DEY
            Y = (Y - 1) And &HFF
            M6502_SetFlags Y
        Case INS_EOR
            A = A Xor Read6502(savepc)
            M6502_SetFlags A
        Case INS_INA
            A = (A + 1) And &HFF
            M6502_SetFlags A
        Case INS_INC
            temp = Read6502(savepc)
            Write6502 savepc, temp
            temp = (temp + 1) And &HFF
            M6502_SetFlags temp
            Write6502 savepc, temp
        Case INS_INX
            X = (X + 1) And &HFF
            M6502_SetFlags X
        Case INS_INY
            Y = (Y + 1) And &HFF
            M6502_SetFlags Y
        Case INS_JMP
            PC = savepc
        Case INS_JSR
            temp = Read6502(PC)
            PC = PC + 1
            Write6502 (S + &H100&), (PC \ &H100&)
            S = (S - 1) And &HFF
            Write6502 (S + &H100&), (PC And &HFF)
            S = (S - 1) And &HFF
            temp2 = Read6502(PC)
            PC = (temp2 * &H100&) + temp
            #If DEBUG_ON Then
                Adr2 = "$" + String(4 - Len(Hex(temp Or (temp2 * &H100&))), "0") + Hex$(temp Or (temp2 * &H100&)) & "   $" & Hex$(temp) & ",$" & Hex$(temp2)
            #End If
        Case INS_LDA
            A = Read6502(savepc)
            M6502_SetFlags A
        Case INS_LDX
            X = Read6502(savepc)
            M6502_SetFlags X
        Case INS_LDY
            Y = Read6502(savepc)
            M6502_SetFlags Y
        Case INS_LSR
            If AddressingModes(opcode) = ADR_ACC Then
                P = ((P And &HFE) Or (A And &H1))
                A = (A \ 2)
                M6502_SetFlags A
            Else
                temp = Read6502(savepc)
                Write6502 savepc, temp
                P = ((P And &HFE) Or (temp And &H1))
                temp2 = (temp \ 2)
                M6502_SetFlags temp2
                Write6502 savepc, temp2
            End If
        Case INS_ORA
            A = A Or Read6502(savepc)
            M6502_SetFlags A
        Case INS_PHA
            Write6502 (S + &H100&), A
            S = (S - 1) And &HFF
        Case INS_PHP
            Write6502 (S + &H100&), (P Or B_FLAG)
            S = (S - 1) And &HFF
        Case INS_PHX
            Write6502 (S + &H100&), X
            S = (S - 1) And &HFF
        Case INS_PHY
            Write6502 (S + &H100&), Y
            S = (S - 1) And &HFF
        Case INS_PLA
            S = (S + 1) And &HFF
            A = Read6502(S + &H100&)
            M6502_SetFlags A
        Case INS_PLP
            S = (S + 1) And &HFF
            P = Read6502(S + &H100&) Or R_FLAG
        Case INS_PLX
            S = (S + 1) And &HFF
            X = Read6502(S + &H100&)
        Case INS_PLY
            S = (S + 1) And &HFF
            Y = Read6502(S + &H100&)
        Case INS_ROL
            temp = (P And C_FLAG)
            If AddressingModes(opcode) = ADR_ACC Then
                help = (A * 2) + temp
                A = (help And &HFF)
                If (help And &H100&) Then
                    P = (P Or C_FLAG)
                Else
                    P = (P And C_OFF)
                End If
                M6502_SetFlags A
            Else
                temp2 = Read6502(savepc)
                Write6502 savepc, temp2
                help = (temp2 * 2) + temp
                temp2 = (help And &HFF)
                M6502_SetFlags temp2
                Write6502 savepc, temp2
                If (help \ &H100&) Then
                    P = (P Or C_FLAG)
                Else
                    P = (P And C_OFF)
                End If
            End If
        Case INS_ROR
            If (P And C_FLAG) Then
                temp2 = &H80
            Else
                temp2 = 0
            End If
            If AddressingModes(opcode) = ADR_ACC Then
                temp = ((A \ 2) Or temp2) And &HFF
                If (A And &H1) Then
                    P = (P Or C_FLAG)
                Else
                    P = (P And C_OFF)
                End If
                A = temp
                M6502_SetFlags A
            Else
                temp = Read6502(savepc)
                Write6502 savepc, temp
                If (temp And &H1) Then
                    P = (P Or C_FLAG)
                Else
                    P = (P And C_OFF)
                End If
                temp = ((temp \ 2) Or temp2) And &HFF
                M6502_SetFlags temp
                Write6502 savepc, temp
            End If
        Case INS_RTI
            S = (S + 1) And &HFF
            P = Read6502(S + &H100&) Or R_FLAG
            S = (S + 1) And &HFF
            temp = Read6502(S + &H100&)
            S = (S + 1) And &HFF
            PC = (Read6502(S + &H100&) * &H100&) Or temp
        Case INS_RTS
            S = (S + 1) And &HFF
            temp = Read6502(S + &H100&)
            S = (S + 1) And &HFF
            PC = (Read6502(S + &H100&) * &H100&) Or temp
            PC = PC + 1
        Case INS_SBC
            temp2 = IIf((P And C_FLAG), 0, 1)
            temp = Read6502(savepc)
            help = A
            help = (help - temp - temp2)
            If ((A Xor temp) And &H80) And ((A Xor help) And &H80) Then
                P = P Or V_FLAG
            Else
                P = P And V_OFF
            End If
            A = (help And &HFF)
            If (help >= &H0) Then
                P = P Or C_FLAG
            Else
                P = P And C_OFF
            End If
            If (CPU_TYPE = CPU_M2A03) Then '2A03 has no decimal mode.
            Else
                If (P And D_FLAG) Then
                    A = (A - &H66) And &HFF
                    P = P And &HFE
                    If ((A And &HF) > &H9) Then
                        A = (A + &H6) And &HFF
                    End If
                    If ((A And &HF0) > &H90) Then
                        A = (A + &H60) And &HFF
                        P = P Or C_FLAG
                    End If
                Else
                    Ticks = Ticks - 1
                End If
            End If
            M6502_SetFlags A
        Case INS_SEC
            P = P Or C_FLAG
        Case INS_SED
            P = P Or D_FLAG
        Case INS_SEI
            P = P Or I_FLAG
        Case INS_STA
            Write6502 savepc, A
        Case INS_STX
            Write6502 savepc, X
        Case INS_STY
            Write6502 savepc, Y
        Case INS_STZ
            Write6502 savepc, 0
        Case INS_TAX
            X = A
            M6502_SetFlags X
        Case INS_TAY
            Y = A
            M6502_SetFlags Y
        Case INS_TRB
            temp = Read6502(savepc)
            Write6502 savepc, temp
            If (temp = 0) Then
                P = P Or Z_FLAG
            Else
                P = P And Z_OFF
            End If
            temp = (temp And (A Xor &HFF))
            Write6502 savepc, temp
        Case INS_TSB
            temp = Read6502(savepc)
            Write6502 savepc, temp
            If (temp = 0) Then
                P = P Or Z_FLAG
            Else
                P = P And Z_OFF
            End If
            temp = (temp Or A)
            Write6502 savepc, temp
        Case INS_TSX
            X = S
            M6502_SetFlags X
        Case INS_TXA
            A = X
            M6502_SetFlags A
        Case INS_TXS
            S = X
        Case INS_TYA
            A = Y
            M6502_SetFlags A
        Case INS_ERA
            #If DEBUG_ON Then
                Add "* Error in exec6502($" & Hex$(opcode) & ");"
            #End If
    End Select

If Ticks <= 0 Then
    If (P And &H4) = 0 Then
      M6502_IRQ
    End If
    M6502_resetTicks
End If

End Sub
#If DEBUG_ON Then
    Public Sub Add(txtAdd As String)
        Debug.Print txtAdd
    End Sub
#End If
Public Sub M6502_Branch(ByVal Condition As Boolean)
    If (Condition = True) Then
        savepc = Read6502(PC)
        PC = PC + 1
        If (savepc And &H80) Then
            savepc = (savepc - &H100&)
        End If
        PC = PC + savepc
        Ticks = Ticks + 1
    Else
        PC = PC + 1
    End If
End Sub
Public Sub M6502_SetFlags(ByVal fSet As Byte)

    If (fSet And &H80) Then
        P = (P Or S_FLAG)
    Else
        P = (P And S_OFF)
    End If
    If (fSet = 0) Then
        P = (P Or Z_FLAG)
    Else
        P = (P And Z_OFF)
    End If

End Sub
Public Sub M6502_resetTicks()
    Ticks = CPU_Ticks
End Sub
Public Sub M6502_Free()
    'delete all associated stuff w/ M6502.
    Erase Stack, gameImage, AddressingModes, Instructions, ClockTicks
    CPURunning = False: CPUPaused = False
End Sub
Public Function Read6502(ByVal Address As Long) As Byte
  Dim valc01 As Byte, valc03 As Byte

  Select Case Address
    Case &HC01&
      valc01 = &HFF
      
      If keyboard(vbKey3) = 1 Then
        valc01 = valc01 Xor &H40
      End If
      
      If keyboard(vbKey1) = 1 Then
        valc01 = valc01 Xor &H1
      End If
      
      If keyboard(vbKeyControl) = 1 Then
        valc01 = valc01 Xor &H4
      End If
      Read6502 = valc01
    Case &HC03&
      valc03 = &HFF
      If keyboard(vbKeyUp) = 1 Then
        valc03 = valc03 Xor &H10
      End If
      If keyboard(vbKeyDown) = 1 Then
        valc03 = valc03 Xor &H20
      End If
      If keyboard(vbKeyLeft) = 1 Then
        valc03 = valc03 Xor &H40
      End If
      If keyboard(vbKeyRight) = 1 Then
        valc03 = valc03 Xor &H80
      End If
      Read6502 = valc03
    Case Else
        Read6502 = gameImage(Address And &H3FFF&)
  End Select

End Function
Public Sub Write6502(ByVal Address As Long, ByVal value As Byte)

  If Address = &H1800 Then
    M6502_resetTicks
  End If
     
  If Address >= &H2000 Then
    Exit Sub
  End If
     
  gameImage(Address) = value
End Sub
#If DEBUG_ON Then
    Public Sub M6502_InitDebug()
        CPU_TYPES(&H0) = "M6502": CPU_TYPES(&H1) = "M65C02": CPU_TYPES(&H2) = "M65SC02"
        CPU_TYPES(&H3) = "M6510": CPU_TYPES(&H4) = "M2A03": CPU_TYPES(&H5) = "M6809"
        AM(0) = "ERR": AM(1) = "$xxxx": AM(2) = "A": AM(3) = ""
        AM(4) = "#$xx": AM(5) = "($xxxx)": AM(6) = "$xxxx,X"
        AM(7) = "$xxxx,Y": AM(8) = "($xx)": AM(9) = "($xxxx,X)"
        AM(10) = "($xxxx),Y": AM(11) = "": AM(12) = "$xx"
        AM(13) = "$xx,X": AM(14) = "$xx,Y"
        'Instructions
        Ins(0) = "ERR": Ins(1) = "ADC": Ins(2) = "AND": Ins(3) = "ASL": Ins(4) = "BBR": Ins(5) = "BBS"
        Ins(6) = "BCC": Ins(7) = "BCS": Ins(8) = "BEQ": Ins(9) = "BIT": Ins(10) = "BMI": Ins(11) = "BNE"
        Ins(12) = "BPL": Ins(13) = "BRA": Ins(14) = "BRK": Ins(15) = "BVC": Ins(16) = "BVS": Ins(17) = "CLC"
        Ins(18) = "CLD": Ins(19) = "CLI": Ins(20) = "CLV": Ins(21) = "CMP": Ins(22) = "CPX": Ins(23) = "CPY"
        Ins(24) = "DEA": Ins(25) = "DEC": Ins(26) = "DEX": Ins(27) = "DEY": Ins(28) = "EOR": Ins(29) = "INA"
        Ins(30) = "INC": Ins(31) = "INX": Ins(32) = "INY": Ins(33) = "JMP": Ins(34) = "JSR": Ins(35) = "LDA"
        Ins(36) = "LDX": Ins(37) = "LDY": Ins(38) = "LSR": Ins(39) = "NOP": Ins(40) = "ORA": Ins(41) = "PHA"
        Ins(42) = "PHP": Ins(43) = "PHX": Ins(44) = "PHY": Ins(45) = "PLA": Ins(46) = "PLP": Ins(47) = "PLX"
        Ins(48) = "PLY": Ins(49) = "ROL": Ins(50) = "ROR": Ins(51) = "RTI": Ins(52) = "RTS": Ins(53) = "SBC"
        Ins(54) = "SEC": Ins(55) = "SED": Ins(56) = "SEI": Ins(57) = "STA": Ins(58) = "STX": Ins(59) = "STY"
        Ins(60) = "STZ": Ins(61) = "TAX": Ins(62) = "TAY": Ins(63) = "TRB": Ins(64) = "TSB": Ins(65) = "TSX"
        Ins(66) = "TXA": Ins(67) = "TXS": Ins(68) = "TYA"
    End Sub
#End If
